BufferView

Struct BufferView 

#[repr(transparent)]
pub struct BufferView(pub NonZeroU64);
VkBufferView : VkDevice

Tuple Fields

0: NonZeroU64

Implementations

Source

impl BufferView

pub fn new(raw: u64) -> Option<Self>

Creates a new BufferView from a raw handle value. Returns None if the value is zero.

pub unsafe fn new_unchecked(raw: u64) -> Self

Creates a new BufferView from a raw handle value without checking if it’s zero. The caller must ensure that the value is not zero.