Framebuffer

Struct Framebuffer 

#[repr(transparent)]
pub struct Framebuffer(pub NonZeroU64);
VkFramebuffer : VkDevice

Tuple Fields

0: NonZeroU64

Implementations

Source

impl Framebuffer

pub fn new(raw: u64) -> Option<Self>

Creates a new Framebuffer from a raw handle value. Returns None if the value is zero.

pub unsafe fn new_unchecked(raw: u64) -> Self

Creates a new Framebuffer from a raw handle value without checking if it’s zero. The caller must ensure that the value is not zero.