MappedMemoryRange

Struct MappedMemoryRange 

#[repr(C)]
pub struct MappedMemoryRange<'a> { pub s_type: StructureType, pub p_next: *const void, pub memory: Option<DeviceMemory>, pub offset: DeviceSize, pub size: DeviceSize, pub _p: PhantomData<&'a ()>, }
VkMappedMemoryRange

Fields

s_type: StructureType
VkStructureType sType

Value: StructureType::MappedMemoryRange

p_next: *const void
void const* pNext

Optional

memory: Option<DeviceMemory>

Mapped memory object

VkDeviceMemory memory
offset: DeviceSize

Offset within the memory object where the range starts

VkDeviceSize offset
size: DeviceSize

Size of the range within the memory object

VkDeviceSize size
_p: PhantomData<&'a ()>

Implementations

Source

impl<'a> MappedMemoryRange<'a>

pub fn new(new: MappedMemoryRange) -> Self

Create the MappedMemoryRange with required fields

Source

impl<'a> MappedMemoryRange<'a>

pub fn memory(self, memory: DeviceMemory) -> Self

Mapped memory object

VkDeviceMemory memory
pub fn offset(self, offset: DeviceSize) -> Self

Offset within the memory object where the range starts

VkDeviceSize offset
pub fn size(self, size: DeviceSize) -> Self

Size of the range within the memory object

VkDeviceSize size