#[repr(transparent)]pub struct Framebuffer(pub NonZeroU64);Expand description
VkFramebuffer : VkDevice
Tuple Fields
0: NonZeroU64Implementations
Sourceimpl Framebuffer
impl Framebuffer
Sourcepub fn new(raw: u64) -> Option<Self>
pub fn new(raw: u64) -> Option<Self>
Creates a new Framebuffer from a raw handle value. Returns None if the value is zero.
Sourcepub unsafe fn new_unchecked(raw: u64) -> Self
pub unsafe fn new_unchecked(raw: u64) -> Self
Creates a new Framebuffer from a raw handle value without checking if it’s zero. The caller must ensure that the value is not zero.