#[repr(transparent)]pub struct Sampler(pub NonZeroU64);Expand description
VkSampler : VkDevice
Tuple Fields
0: NonZeroU64Implementations
Sourceimpl Sampler
impl Sampler
Sourcepub fn new(raw: u64) -> Option<Self>
pub fn new(raw: u64) -> Option<Self>
Creates a new Sampler from a raw handle value. Returns None if the value is zero.
Sourcepub unsafe fn new_unchecked(raw: u64) -> Self
pub unsafe fn new_unchecked(raw: u64) -> Self
Creates a new Sampler from a raw handle value without checking if it’s zero. The caller must ensure that the value is not zero.